@@ -6,17 +6,19 @@ missing,
 handling_missing,
 drop_columns,
 plot_categorical,
-plot_quantitative,
+plot_numerical,
 view_cardinality,
 modify_cardinality,
 correlation_pearson,
 correlation_categorical,
 correlation_phik,
-quant_variable_study,
+num_variable_study,
 interaction,
 inspection,
 split_and_scaling)
 
-from .reg import (TrainRegressor, load_model, regression_metrics)
+from .regression import (TrainRegressor, regression_metrics)
 
-__version__ = "0.22"
+from .tools import (load_model, setup, scaling)
+
+__version__ = "0.27"
